@@ -1,5 +1,4 @@
-/* xscreensaver, Copyright (c) 1992, 1996, 1997, 1998, 2005, 2006
- *  Jamie Zawinski <jwz@jwz.org>
+/* xscreensaver, Copyright (c) 1992-2008 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -569,6 +568,7 @@ static const char *noseguy_defaults [] = {
   ".foreground:	    #CCCCCC",
   "*textForeground: black",
   "*textBackground: #CCCCCC",
+  "*fpsSolid:	true",
   "*program:	 xscreensaver-text --cols 40 | head -n15",
   ".font:	 -*-new century schoolbook-*-r-*-*-*-180-*-*-*-*-*-*",
   0
